==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicMenuUI__24MenuHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuUI$MenuHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 10cb5c57e89e2cc8 javax_swing_plaf_basic_BasicMenuUI__24MenuHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_MenuEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$_init$7ba31f1d1d7c381f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$menuCanceled$a4726b4331c5be82(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$menuDeselected$bbbe46f4a9f55140(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *);
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$menuSelected$38669eeacd2a024b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method_info$menuCanceled$a4726b4331c5be82;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method_info$menuDeselected$bbbe46f4a9f55140;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method_info$menuSelected$38669eeacd2a024b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods {
	void	(*menuCanceled$a4726b4331c5be82)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *);
	void	(*menuDeselected$bbbe46f4a9f55140)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *);
	void	(*menuSelected$38669eeacd2a024b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods	javax_swing_plaf_basic_BasicMenuUI__24MenuHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs	javax_swing_plaf_basic_BasicMenuUI__24MenuHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuUI__24MenuHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuUI__24MenuHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicMenuUI__24MenuHandler.h <==
// public class javax.swing.plaf.basic.BasicMenuUI$MenuHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 10cb5c57e89e2cc8 javax_swing_plaf_basic_BasicMenuUI__24MenuHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler_H_
#define _JC_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_MenuEvent$object;
struct _jc_javax_swing_plaf_basic_BasicMenuUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$_init$7ba31f1d1d7c381f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_plaf_basic_BasicMenuUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$menuCanceled$a4726b4331c5be82(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$menuDeselected$bbbe46f4a9f55140(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method$menuSelected$38669eeacd2a024b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method_info$menuCanceled$a4726b4331c5be82;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method_info$menuDeselected$bbbe46f4a9f55140;
extern _jc_method _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$method_info$menuSelected$38669eeacd2a024b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods {
	void	(*menuCanceled$a4726b4331c5be82)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *) _JC_JCNI_ATTR;
	void	(*menuDeselected$bbbe46f4a9f55140)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *) _JC_JCNI_ATTR;
	void	(*menuSelected$38669eeacd2a024b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object *, struct _jc_javax_swing_event_MenuEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vmethods	javax_swing_plaf_basic_BasicMenuUI__24MenuHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicMenuUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs {
    _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_refs	javax_swing_plaf_basic_BasicMenuUI__24MenuHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$sub_nonrefs	javax_swing_plaf_basic_BasicMenuUI__24MenuHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$object {
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$vtype _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicMenuUI__24MenuHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicMenuUI__24MenuHandler_H_ */
